@@ -22,8 +22,7 @@ def get_access_token(corpid, secret) -> (str, int):
         - access_token: 获取到的凭证，最长为512字节
         - expires_in: 凭证的有效时间（秒），通常为7200
     """
-    url = WECHATWORK_API_ROOT_URL + 'gettoken?corpid={corpid}&corpsecret={secret}' \
-        .format(corpid=corpid, secret=secret)
+    url = f'{WECHATWORK_API_ROOT_URL}/gettoken?corpid={corpid}&corpsecret={secret}'
     data = json.loads(requests.get(url).content)
     if int(data['errcode']) == 0:
         return data['access_token'], int(data['expires_in'])
